unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, AppEvnts, DirectDraw;

type
  TForm1 = class(TForm)
    ApplicationEvents1: TApplicationEvents;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FormPaint(Sender: TObject);
    procedure ApplicationEvents1Restore(Sender: TObject);
    procedure ApplicationEvents1Deactivate(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
  private
    { Private declarations }
    FDirectDraw : IDirectDraw7;
    FPrimarySurface : IDirectDrawSurface7;
    BKBitmap : TBitmap;
    procedure ErrorOut(hRet : HRESULT);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.ErrorOut(hRet: HRESULT);
begin
 MessageBox(0, PChar(DDErrorString(hRet)), '', MB_OK or MB_ICONSTOP);
end;

procedure TForm1.FormCreate(Sender: TObject);
var
 hRet : HRESULT;
 SurfaceDesc : TDDSurfaceDesc2;
begin
 FPrimarySurface := nil;
 FDirectDraw := nil;

 hRet := DirectDrawCreateEx (nil, FDirectDraw, IDirectDraw7, nil);
 if hRet <> DD_OK then 
  begin
   ErrorOut(hRet);
   Close;
   Exit;
  end;

 hRet := FDirectDraw.SetCooperativeLevel(Handle, DDSCL_FULLSCREEN or DDSCL_EXCLUSIVE);
 if hRet <> DD_OK then
  begin
   ErrorOut(hRet);
   Close;
   Exit;
  end;

 hRet := FDirectDraw.SetDisplayMode (640, 480, 16, 0, 0);
 if hRet <> DD_OK then
  begin
   ErrorOut(hRet);
   Close;
   Exit;
  end;

 FillChar (SurfaceDesc, SizeOf(SurfaceDesc), 0);
 SurfaceDesc.dwSize := SizeOf(SurfaceDesc);
 SurfaceDesc.dwFlags := DDSD_CAPS;
 SurfaceDesc.ddsCaps.dwCaps := DDSCAPS_PRIMARYSURFACE;
 hRet := FDirectDraw.CreateSurface(SurfaceDesc, FPrimarySurface, nil);
 if hRet <> DD_OK then
  begin
   ErrorOut(hRet);
   Close;
   Exit;
  end;

 BkBitmap := TBitmap.Create;
 BkBitmap.LoadFromFile ('1.bmp');
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
 if Assigned(FPrimarySurface) then FPrimarySurface := nil;
 if Assigned(FDirectDraw) then FDirectDraw := nil;
 BkBitmap.Free;
end;

procedure TForm1.FormPaint(Sender: TObject);
var
 DC : HDC;
 TempCanvas : TCanvas;
 hRet : HRESULT;
 bltfx : TDDBLTFX;
begin
 ZeroMemory(@bltfx, SizeOf(bltfx));
 bltfx.dwSize := sizeof(bltfx);
 bltfx.dwFillColor := 0;
 while True do
  begin
   hRet := FPrimarySurface.Blt(nil, nil, nil, DDBLT_COLORFILL or DDBLT_WAIT, @bltfx);
   if hRet = DDERR_SURFACELOST then
    begin
     hRet := FPrimarySurface._Restore;
     if hRet <> DD_OK then Break;
    end 
   else Break;
  end;

 hRet := FPrimarySurface.GetDC(DC);
 if hRet=0 then
  begin
   TempCanvas := TCanvas.Create;
   TempCanvas.Handle := DC;
   TempCanvas.Draw(95, 15, BkBitmap);
   TempCanvas.Free;
   FPrimarySurface.ReleaseDC (DC);
  end;
end;

procedure TForm1.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
 if Key=VK_ESCAPE then Close;
end;

procedure TForm1.ApplicationEvents1Restore(Sender: TObject);
begin
 WindowState := wsMaximized;
end;

procedure TForm1.ApplicationEvents1Deactivate(Sender: TObject);
begin
 Application.Minimize;
end;

end.
